==> bodhi-cli-0.6.16.tgz: package/bin/modeler.js <==
#!/usr/bin/env node

var cli     = require('yargs')
  , path    = require('path')
  , fs      = require('fs-extra')
  , findup  = require('findup')
  , M       = require('mstring')
  , format  = require('format-json-stream')
  , package = require('../package.json')
  , Client  = require('rbc-rest-client')
  , Resource= require('../lib/types').Resource
  , Embedded= require('../lib/types').Embedded
  , Property= require('../lib/types').Property
  , project = require('../lib/project')
    , LocalTypeController        = require('../lib/controllers/LocalTypeController')
    , RemoteTypeController       = require('../lib/controllers/RemoteTypeController')
  , _       = require('../lib/utils')
  , viewHelper           = require('../lib/views')
  ;

  var usage = M(function(){
    /***

     $0 [processing-options] <command> [args]

     //- Local Type Commands
     $0 new      | create    <model-name>  -n <namespace>   [type-options]
     $0 rename   | mv        <from> <to>  [-n <namespace>]
     $0 edit     | modify    <model-name> [-n <namespace>] [type-options]
     $0 view     | print     <model-name>
     $0 remove   | rm        <model-name>

     //- Local Property Commands
     $0 view-props  <model-name>
     $0 set-prop    <model-name> <property-name> [property options]
     $0 rename-prop <model-name> <to> <from>
     $0 del-prop    <model-name> <property-name>

     //- Remote Commands
     $0 list     | ls,ll     [-e <environment>]
     $0 list-props           <model-name> [-e <environment>]
     $0 get      | read      <model-name> [-e <environment>]
     $0 fetch    | download  <model-name> [-e <environment>]
     $0 download | pull      <model-name> [-e <environment>]
     $0 post     | push      <model-name> [-e <environment>]
     $0 delete   | destroy   <model-name> [-e <environment>]

     ***/})

  var argv = cli
        .usage(usage)
        .options('e', {alias:'environment', describe: 'The environment to use'})

        //- Type Option Options
        .options('storage_name' , {describe: 'mark the type as embedded'})
        .boolean('embedded'    , {describe: 'name of the collection'       , default: false})
        .options('immutable'   , {describe: 'mark the type as immutable'   , default: false})
        .options('encapsulated', {describe: 'mark the type as encapsulated', default: false})
        .options('extensible'  , {describe: 'mark the type as extensible'  , default: false})

        //- Property Options
        .boolean('u', {describe: 'mark property as unique', default: false})
        .alias('u', 'unique')
        .boolean('r', {describe: 'mark property as required', default: false})
        .alias('r', 'required')
        .boolean('m', {describe: 'mark property as a multi valued', default: false})
        .alias('m', 'multi')
        .options('s', {alias:'scale',     describe: 'set the scale of a decimal property'})
        .options('d', {alias:'default',   describe: 'set the default value'})
        .options('t', {alias:'type',      describe: 'set the property type'})
        .options('O', {alias:'Object',  type: 'boolean',  describe: 'set the property type as an Object'})
        .options('B', {alias:'Boolean', type: 'boolean',  describe: 'set the property type as Boolean'})
        .options('I', {alias:'Integer', type: 'boolean',  describe: 'set the property type as Integer'})
        .options('R', {alias:'Real',    type: 'boolean',  describe: 'set the property type as Real'})
        .options('S', {alias:'String',  type: 'boolean',  describe: 'set the property type as String'})
        .options('T', {alias:'DateTime',type: 'boolean',  describe: 'set the property type as a DateTime'})
        .options('D', {alias:'Decimal', type: 'boolean',  describe: 'set the property type as a Decimal'})
        .options('C', {alias:'Currency',type: 'boolean',  describe: 'set the property type as a Currency'})
        .options('G', {alias:'GeoJSON' ,type: 'boolean',  describe: 'set the property type as a GeoJSON'})
        .options('L', {alias:'Link'    ,type: 'boolean',  describe: 'set the property type as a Link'})

        //View Options

        //Processing options
        .options('f', {alias: "force"  , describe: 'Force the command',    type: 'boolean', default: false})
        .options('v', {alias: "verbose", describe: 'more detailed output', type: 'boolean', default: false})
        .options('V', {alias: "version", describe: 'Print version number of the tool'})

        .argv
        ;

//Just want the version
if(argv.version){
    console.log(package.version);
    return;
}

//Just want the help
if(argv.help){
    cli.showHelp()
    return;
}

function CLI(options){

    this.helpers = require('../lib/helpers')(argv);

    //Map functions from helpers
    this.project      = this.helpers.loadProjectSync();
    this.createEnv    = this.helpers.createEnv;

    //Setup the Controllers
    this.controllers = {
        local    : LocalTypeController(this.project, options),
        remote   : RemoteTypeController(this.project, options)
    }
}

CLI.prototype = {

    dispatch: function(argv){

        //Consume the action
        var action = (argv._ && argv._.length > 0) ? argv._.shift() : '';
        this.action = action.toLowerCase();

        switch(action){
            case '':
                break;
            case 'info':
                if(argv.debug) console.log('info');
                this.info();
                break;
            case 'new':
            case 'create':
                if(argv.debug) console.log('create');
                this.create(argv);
                break;
            case 'mv':
            case 'rename':
                if(argv.debug) console.log('rename');
                this.rename(argv);
                break;
            case 'edit':
            case 'modify':
                if(argv.debug) console.log('edit');
                this.edit(argv);
                break;
            case 'view':
            case 'print':
                if(argv.debug) console.log('echo');
                this.echo(argv);
                break;
            case 'rm':
            case 'remove':
                if(argv.debug) console.log('remove');
                this.remove(argv);
                break;
            case 'ls':
            case 'list':
                if(argv.debug) console.log('list');
                this.list(argv);
                break;
            case 'lp':
            case 'list-props':
                if(argv.debug) console.log('list');
                this.lsProps(argv);
                break;
            case 'get':
                if(argv.debug) console.log('show');
                this.get(argv);
                break;
            case 'fetch':
            case 'pull':
            case 'download':
                if(argv.debug) console.log('pull');
                this.fetch(argv);
                break;
            case 'post':
            case 'push':
            case 'upload':
                if(argv.debug) console.log('push');
                this.post(argv);
                break;
            case 'delete':
            case 'destroy':
                if(argv.debug) console.log('destroy');
                this.destroy(argv);
                break;
            case 'view-props':
            case 'print-props':
                if(argv.debug) console.log('echo-property');
                this.echoProps(argv);
                break;
            case 'set-prop':
                if(argv.debug) console.log('add-property');
                this.setProperty(argv);
                break;
            case 'mv-prop':
            case 'rename-prop':
                if(argv.debug) console.log('rename a property');
                this.mvProperty(argv);
                break;
            case 'rm-prop':
            case 'del-prop':
                if(argv.debug) console.log('install');
                this.rmProperty(argv);
                break;
            case 'gen-instance':
                if(argv.debug) console.log('install');
                this.genInstance(argv);
                break;
            default:
                console.log('Unknown Command: ' + action);
                break;
        }
    },

    /*

     create : create,
     rename : rename,
     view   : view,
     edit   : edit,
     remove : remove,
     putProp: mvProp,
     mvProp : mvProp,
     rmProp : rmProp

     post    : create,
     put     : update,
     list    : list,
     get     : get,
     download: download,
     delete  : destroy

     */
    info: function(){

        var logo;
        try{
            logo = fs.readFileSync(path.join(__dirname, '..', 'lib', 'assets', 'types.txt'), 'utf-8');
        } catch (e){}

        if(logo) console.log(logo);
        console.log('bodhi-types' + ' v' + package.version);
        console.log('A command line tool for creating and interacting with the Bodhi type system');
        console.log('Licensed under ' + package.license);
        console.log('\u00A9 2015 HotSchedules Inc.');
    },

    /**
     * Create the model
     */
    create  : function create(argv){

        //map
        var name        = argv._.shift();

        //test
        if(!name){
            console.log('Missing Argument: Unspecified Name.')
        } else {
            this.controllers['local'].create(name, argv);
        }
    },

    rename  : function rename(argv){

        //inputs
        var from      = argv._.shift()
          , to        = argv._.shift();

        if(!from){
            return console.log('Missing Argument: Unspecified Name.');
        }

        if(!to){
            return console.log('Missing Argument: Unspecified new Name.');
        }

        return this.controllers['local'].rename(from, to);
    },

    /**
     * Show a local model
     */
    echo    : function echo(argv){
        var name = argv._.shift();

        if(!name){
            return console.log('Missing Argument: Unspecified Name');
        }

        this.controllers['local'].view(name, viewHelper.View(viewHelper.createSpec(argv)));
    },

    echoProps    : function echoProps(argv){
        var name = argv._.shift();

        if(!name){
            return console.log('Missing Argument: Unspecified Name');
        }

        this.controllers['local'].getProps(name);
    },

    /**
     * Get the model from the server
     */
    edit   : function edit(){

        //map
        var name = argv._.shift();

        //test
        if(!name){
            return console.log('Missing Argument: Unspecified Name');
        }

        this.controllers['local'].edit(name, argv);

    },

    /**
     * Delete Locally
     */
    remove: function remove(argv){

        var name        = argv._.shift();

        if(!name){
            return console.log('Missing Argument: Unspecified Name');
        }

        return this.controllers['local'].remove(name);
    },

    /**
     * View a model
     */
    get    : function(argv){
        var name = argv._.shift()
          , env  = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv);
        this.controllers['remote'].get(env, name, (viewHelper.createSpec(argv)));
    },

    /**
     * View a model
     */
    lsProps : function(argv){

        var name = argv._.shift()
            , env  = this.createEnv(this.project, argv);

        this.demandEnvOrExit(env, argv);

        this.controllers['remote'].listProps(env, name);
    },

    /**
     * Fetch the object from the server and write to a file
     */
    fetch   : function(argv){
        var name = argv._.shift()
        ,   env  = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv);
        this.controllers['remote'].download(env, name, viewHelper.createSpec(argv));
    },


    post   : function(argv){
        var name        = argv._.shift()
          , env         = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv);
        this.controllers['remote'].post(env, name);
    },

    put   : function(argv){

        var name        = argv._.shift()
          , env         = this.createEnv(this.project, argv);

        this.demandEnvOrExit(env, argv);
        this.controllers['remote'].put(env, name);
    },

    /**
     * List the models
     *
     * ls
     * list -l --local -r --remote -p --properties
     * ll - list local
     * lr - list remote
     *
     *
     *
     */
    list    : function(argv){
        var env = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv)
        this.controllers['remote'].list(env, viewHelper.View(viewHelper.createSpec(argv)));
    },

    /**
     * Delete from the server
     */
    destroy : function(argv){

        var name = argv._.shift()
          , env  = this.createEnv(this.project, argv);

        //EnsureEnvironment
        this.demandEnvOrExit(env, argv);

        //test
        if(!name){
            return console.error('Error: Unspecified Name')
        }

        return this.controllers['remote'].delete(env, name)
    },

    setProperty: function(argv){
        var type_name = argv._.shift()
          , props     = argv._;

        this.controllers['local'].putProp(type_name, props, argv)
    },

    rmProperty: function(){
        var type_name = argv._.shift()
          , prop_name = argv._.shift();

        this.controllers['local'].rmProp(type_name);
    },

    mvProperty: function(){

        var type_name = argv._.shift();
        var from_name = argv._.shift();
        var to_name   = argv._.shift();

        this.controllers['local'].mvProp(type_name, from_name, to_name);
    },

    genInstance: function(){
        var type_name = argv._.shift();
        this.controllers['local'].genInstance(type_name);
    },

    demandEnvOrExit: function(env, argv){
        if(!env){
            console.log("Unknown environment " + argv.environment);
            process.exit(1);
        }
    },

    fatal: function (msg, code){
        code = code || 5;
        console.log('Fatal Error' + ' ' + msg);
        process.exit(code);
    }
};


//var cli = new app().dispatch(argv);
//var cli = require('CommandProcessor')(options).createCommand(argv).execute()
var cmd = new CLI(argv).dispatch(argv);

==> bodhi-cli-0.7.5.tgz: package/bin/modeler.js <==
#!/usr/bin/env node

var cli     = require('yargs')
  , path    = require('path')
  , fs      = require('fs-extra')
  , findup  = require('findup')
  , M       = require('mstring')
  , format  = require('format-json-stream')
  , package = require('../package.json')
  , Client  = require('rbc-rest-client')
  , Resource= require('../lib/types').Resource
  , Embedded= require('../lib/types').Embedded
  , Property= require('../lib/types').Property
  , project = require('../lib/project')
    , LocalTypeController        = require('../lib/controllers/LocalTypeController')
    , RemoteTypeController       = require('../lib/controllers/RemoteTypeController')
  , _       = require('../lib/utils')
  , viewHelper           = require('../lib/views')
  ;

  var usage = M(function(){
    /***

     $0 [processing-options] <command> [args]

     //- Local Type Commands
     $0 new      | create    <model-name>  -n <namespace>   [type-options]
     $0 rename   | mv        <from> <to>  [-n <namespace>]
     $0 edit     | modify    <model-name> [-n <namespace>] [type-options]
     $0 view     | print     <model-name>
     $0 remove   | rm        <model-name>

     //- Local Property Commands
     $0 view-props  <model-name>
     $0 set-prop    <model-name> <property-name> [property options]
     $0 rename-prop <model-name> <to> <from>
     $0 del-prop    <model-name> <property-name>

     //- Remote Commands
     $0 list     | ls,ll     [-e <environment>]
     $0 list-props           <model-name> [-e <environment>]
     $0 get      | read      <model-name> [-e <environment>]
     $0 fetch    | download  <model-name> [-e <environment>]
     $0 download | pull      <model-name> [-e <environment>]
     $0 post     | push      <model-name> [-e <environment>]
     $0 delete   | destroy   <model-name> [-e <environment>]

     ***/})

  var argv = cli
        .usage(usage)
        .options('e', {alias:'environment', describe: 'The environment to use'})

        //- Type Option Options
        .options('storage_name' , {describe: 'mark the type as embedded'})
        .boolean('embedded'    , {describe: 'name of the collection'       , default: false})
        .options('immutable'   , {describe: 'mark the type as immutable'   , default: false})
        .options('encapsulated', {describe: 'mark the type as encapsulated', default: false})
        .options('extensible'  , {describe: 'mark the type as extensible'  , default: false})

        //- Property Options
        .boolean('u', {describe: 'mark property as unique', default: false})
        .alias('u', 'unique')
        .boolean('r', {describe: 'mark property as required', default: false})
        .alias('r', 'required')
        .boolean('m', {describe: 'mark property as a multi valued', default: false})
        .alias('m', 'multi')
        .options('s', {alias:'scale',     describe: 'set the scale of a decimal property'})
        .options('d', {alias:'default',   describe: 'set the default value'})
        .options('t', {alias:'type',      describe: 'set the property type'})
        .options('O', {alias:'Object',  type: 'boolean',  describe: 'set the property type as an Object'})
        .options('B', {alias:'Boolean', type: 'boolean',  describe: 'set the property type as Boolean'})
        .options('I', {alias:'Integer', type: 'boolean',  describe: 'set the property type as Integer'})
        .options('R', {alias:'Real',    type: 'boolean',  describe: 'set the property type as Real'})
        .options('S', {alias:'String',  type: 'boolean',  describe: 'set the property type as String'})
        .options('T', {alias:'DateTime',type: 'boolean',  describe: 'set the property type as a DateTime'})
        .options('D', {alias:'Decimal', type: 'boolean',  describe: 'set the property type as a Decimal'})
        .options('C', {alias:'Currency',type: 'boolean',  describe: 'set the property type as a Currency'})
        .options('G', {alias:'GeoJSON' ,type: 'boolean',  describe: 'set the property type as a GeoJSON'})
        .options('L', {alias:'Link'    ,type: 'boolean',  describe: 'set the property type as a Link'})

        //View Options

        //Processing options
        .options('f', {alias: "force"  , describe: 'Force the command',    type: 'boolean', default: false})
        .options('v', {alias: "verbose", describe: 'more detailed output', type: 'boolean', default: false})
        .options('V', {alias: "version", describe: 'Print version number of the tool'})

        .argv
        ;

//Just want the version
if(argv.version){
    console.log(package.version);
    return;
}

//Just want the help
if(argv.help){
    cli.showHelp()
    return;
}

function CLI(options){

    this.helpers = require('../lib/helpers')(argv);

    //Map functions from helpers
    this.project      = this.helpers.loadProjectSync();
    this.createEnv    = this.helpers.createEnv;

    //Setup the Controllers
    this.controllers = {
        local    : LocalTypeController(this.project, options),
        remote   : RemoteTypeController(this.project, options)
    }
}

CLI.prototype = {

    dispatch: function(argv){

        //Consume the action
        var action = (argv._ && argv._.length > 0) ? argv._.shift() : '';
        this.action = action.toLowerCase();

        switch(action){
            case '':
                break;
            case 'info':
                if(argv.debug) console.log('info');
                this.info();
                break;
            case 'new':
            case 'create':
                if(argv.debug) console.log('create');
                this.create(argv);
                break;
            case 'mv':
            case 'rename':
                if(argv.debug) console.log('rename');
                this.rename(argv);
                break;
            case 'edit':
            case 'modify':
                if(argv.debug) console.log('edit');
                this.edit(argv);
                break;
            case 'view':
            case 'print':
                if(argv.debug) console.log('echo');
                this.echo(argv);
                break;
            case 'rm':
            case 'remove':
                if(argv.debug) console.log('remove');
                this.remove(argv);
                break;
            case 'ls':
            case 'list':
                if(argv.debug) console.log('list');
                this.list(argv);
                break;
            case 'lp':
            case 'list-props':
                if(argv.debug) console.log('list');
                this.lsProps(argv);
                break;
            case 'get':
                if(argv.debug) console.log('show');
                this.get(argv);
                break;
            case 'fetch':
            case 'pull':
            case 'download':
                if(argv.debug) console.log('pull');
                this.fetch(argv);
                break;
            case 'post':
            case 'push':
            case 'upload':
                if(argv.debug) console.log('push');
                this.post(argv);
                break;
            case 'alter':
            case 'put':
                if(argv.debug) console.log('push');
                this.put(argv);
                break;
            case 'delete':
            case 'destroy':
                if(argv.debug) console.log('destroy');
                this.destroy(argv);
                break;
            case 'view-props':
            case 'print-props':
                if(argv.debug) console.log('echo-property');
                this.echoProps(argv);
                break;
            case 'set-prop':
                if(argv.debug) console.log('add-property');
                this.setProperty(argv);
                break;
            case 'mv-prop':
            case 'rename-prop':
                if(argv.debug) console.log('rename a property');
                this.mvProperty(argv);
                break;
            case 'rm-prop':
            case 'del-prop':
                if(argv.debug) console.log('deleting a property');
                this.rmProperty(argv);
                break;
            case 'gen-instance':
                if(argv.debug) console.log('generating an instance');
                this.genInstance(argv);
                break;
            default:
                console.log('Unknown Command: ' + action);
                break;
        }
    },

    /*

     create : create,
     rename : rename,
     view   : view,
     edit   : edit,
     remove : remove,
     putProp: mvProp,
     mvProp : mvProp,
     rmProp : rmProp

     post    : create,
     put     : update,
     list    : list,
     get     : get,
     download: download,
     delete  : destroy

     */
    info: function(){

        var logo;
        try{
            logo = fs.readFileSync(path.join(__dirname, '..', 'lib', 'assets', 'types.txt'), 'utf-8');
        } catch (e){}

        if(logo) console.log(logo);
        console.log('bodhi-types' + ' v' + package.version);
        console.log('A command line tool for creating and interacting with the Bodhi type system');
        console.log('Licensed under ' + package.license);
        console.log('\u00A9 2015 HotSchedules Inc.');
    },

    /**
     * Create the model
     */
    create  : function create(argv){

        //map
        var name        = argv._.shift();

        //test
        if(!name){
            console.log('Missing Argument: Unspecified Name.')
        } else {
            this.controllers['local'].create(name, argv);
        }
    },

    rename  : function rename(argv){

        //inputs
        var from      = argv._.shift()
          , to        = argv._.shift();

        if(!from){
            return console.log('Missing Argument: Unspecified Name.');
        }

        if(!to){
            return console.log('Missing Argument: Unspecified new Name.');
        }

        return this.controllers['local'].rename(from, to);
    },

    /**
     * Show a local model
     */
    echo    : function echo(argv){
        var name = argv._.shift();

        if(!name){
            return console.log('Missing Argument: Unspecified Name');
        }

        this.controllers['local'].view(name, viewHelper.View(viewHelper.createSpec(argv)));
    },

    echoProps    : function echoProps(argv){
        var name = argv._.shift();

        if(!name){
            return console.log('Missing Argument: Unspecified Name');
        }

        this.controllers['local'].getProps(name);
    },

    /**
     * Get the model from the server
     */
    edit   : function edit(){

        //map
        var name = argv._.shift();

        //test
        if(!name){
            return console.log('Missing Argument: Unspecified Name');
        }

        this.controllers['local'].edit(name, argv);

    },

    /**
     * Delete Locally
     */
    remove: function remove(argv){

        var name        = argv._.shift();

        if(!name){
            return console.log('Missing Argument: Unspecified Name');
        }

        return this.controllers['local'].remove(name, argv);
    },

    /**
     * View a model
     */
    get    : function(argv){
        var name = argv._.shift()
          , env  = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv);
        this.controllers['remote'].get(env, name, (viewHelper.createSpec(argv)));
    },

    /**
     * View a model
     */
    lsProps : function(argv){

        var name = argv._.shift()
            , env  = this.createEnv(this.project, argv);

        this.demandEnvOrExit(env, argv);

        this.controllers['remote'].listProps(env, name);
    },

    /**
     * Fetch the object from the server and write to a file
     */
    fetch   : function(argv){
        var name = argv._.shift()
        ,   env  = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv);
        this.controllers['remote'].download(env, name, viewHelper.createSpec(argv));
    },

    post   : function(argv){
        var name        = argv._.shift()
          , env         = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv);
        this.controllers['remote'].post(env, name);
    },

    put   : function(argv){
        var name        = argv._.shift()
          , env         = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv);
        this.controllers['remote'].update(env, name);
    },

    /**
     * List the models
     *
     * ls
     * list -l --local -r --remote -p --properties
     * ll - list local
     * lr - list remote
     *
     *
     *
     */
    list    : function(argv){
        var env = this.createEnv(this.project, argv);
        this.demandEnvOrExit(env, argv)
        this.controllers['remote'].list(env, viewHelper.View(viewHelper.createSpec(argv)));
    },

    /**
     * Delete from the server
     */
    destroy : function(argv){

        var name = argv._.shift()
          , env  = this.createEnv(this.project, argv);

        //EnsureEnvironment
        this.demandEnvOrExit(env, argv);

        //test
        if(!name){
            return console.error('Error: Unspecified Name')
        }

        return this.controllers['remote'].delete(env, name)
    },

    setProperty: function(argv){
        var type_name = argv._.shift()
          , props     = argv._;

        this.controllers['local'].putProp(type_name, props, argv)
    },

    rmProperty: function(){
        var type_name = argv._.shift()
          , prop_name = argv._.shift();
        this.controllers['local'].rmProp(type_name, prop_name);
    },

    mvProperty: function(){

        var type_name = argv._.shift();
        var from_name = argv._.shift();
        var to_name   = argv._.shift();

        this.controllers['local'].mvProp(type_name, from_name, to_name);
    },

    genInstance: function(){
        var type_name = argv._.shift();
        this.controllers['local'].genInstance(type_name);
    },

    demandEnvOrExit: function(env, argv){
        if(!env){
            console.log("Unknown environment " + argv.environment);
            process.exit(1);
        }
    },

    fatal: function (msg, code){
        code = code || 5;
        console.log('Fatal Error' + ' ' + msg);
        process.exit(code);
    }
};


//var cli = new app().dispatch(argv);
//var cli = require('CommandProcessor')(options).createCommand(argv).execute()
var cmd = new CLI(argv).dispatch(argv);
